Module: Google::Cloud::SecurityCenter
- Defined in:
- lib/google/cloud/security_center.rb,
lib/google/cloud/security_center/version.rb
Constant Summary collapse
- VERSION =
"2.2.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.security_center| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-security_center library.
-
.security_center(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for SecurityCenter.
-
.security_center_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the SecurityCenter service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.security_center| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-security_center library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
147 148 149 150 151 |
# File 'lib/google/cloud/security_center.rb', line 147 def self.configure yield ::Google::Cloud.configure.security_center if block_given? ::Google::Cloud.configure.security_center end |
.security_center(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for SecurityCenter.
By default, this returns an instance of
Google::Cloud::SecurityCenter::V2::SecurityCenter::Client
for a gRPC client for version V2 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the SecurityCenter service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the SecurityCenter service. You can determine whether the method will succeed by calling security_center_available?.
About SecurityCenter
V2 APIs for Security Center service.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/security_center.rb', line 75 def self.security_center version: :v2, transport: :grpc, &block require "google/cloud/security_center/#{version.to_s.downcase}" package_name = Google::Cloud::SecurityCenter .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::SecurityCenter.const_get(package_name).const_get(:SecurityCenter) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.security_center_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the SecurityCenter service is supported by the current client. If true, you can retrieve a client object by calling security_center. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the SecurityCenter service, or if the versioned client gem needs an update to support the SecurityCenter service.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/google/cloud/security_center.rb', line 99 def self.security_center_available? version: :v2, transport: :grpc require "google/cloud/security_center/#{version.to_s.downcase}" package_name = Google::Cloud::SecurityCenter .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::SecurityCenter.const_get package_name return false unless service_module.const_defined? :SecurityCenter service_module = service_module.const_get :SecurityCenter if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |